=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2011-08-15 15:27:42 +0000
+++ drizzled/sql_lex.cc	2011-10-10 12:58:39 +0000
@@ -169,8 +169,8 @@
 
   /* NOTE: utf_txt.length is in bytes, not in symbols. */
 
-  memcpy(m_body_utf8_ptr, txt->str, txt->length);
-  m_body_utf8_ptr += txt->length;
+  memcpy(m_body_utf8_ptr, txt->data(), txt->size());
+  m_body_utf8_ptr += txt->size();
   *m_body_utf8_ptr= 0;
 
   m_cpp_utf8_processed_ptr= end_ptr;

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-09-19 09:31:36 +0000
+++ drizzled/sql_parse.cc	2011-10-10 12:58:39 +0000
@@ -835,7 +835,7 @@
         !(((Item_func*)default_value)->functype() == Item_func::NOW_FUNC &&
          (type == DRIZZLE_TYPE_TIMESTAMP or type == DRIZZLE_TYPE_MICROTIME)))
     {
-      my_error(ER_INVALID_DEFAULT, MYF(0), field_name->str);
+      my_error(ER_INVALID_DEFAULT, MYF(0), field_name->data());
       return true;
     }
     else if (default_value->type() == Item::NULL_ITEM)
@@ -843,25 +843,25 @@
       default_value= 0;
       if ((type_modifier & (NOT_NULL_FLAG | AUTO_INCREMENT_FLAG)) == NOT_NULL_FLAG)
       {
-        my_error(ER_INVALID_DEFAULT, MYF(0), field_name->str);
+        my_error(ER_INVALID_DEFAULT, MYF(0), field_name->data());
         return true;
       }
     }
     else if (type_modifier & AUTO_INCREMENT_FLAG)
     {
-      my_error(ER_INVALID_DEFAULT, MYF(0), field_name->str);
+      my_error(ER_INVALID_DEFAULT, MYF(0), field_name->data());
       return true;
     }
   }
 
   if (on_update_value && (type != DRIZZLE_TYPE_TIMESTAMP and type != DRIZZLE_TYPE_MICROTIME))
   {
-    my_error(ER_INVALID_ON_UPDATE, MYF(0), field_name->str);
+    my_error(ER_INVALID_ON_UPDATE, MYF(0), field_name->data());
     return true;
   }
 
   CreateField* new_field= new CreateField;
-  if (new_field->init(session, field_name->str, type, length, decimals, type_modifier, *comment, change, interval_list, cs, 0, column_format)
+  if (new_field->init(session, field_name->data(), type, length, decimals, type_modifier, *comment, change, interval_list, cs, 0, column_format)
       || new_field->setDefaultValue(default_value, on_update_value))
     return true;
 
@@ -904,7 +904,7 @@
 
   if (!table)
     return NULL;				// End of memory
-  const char* alias_str= alias ? alias->str : table->table.str;
+  const char* alias_str= alias ? alias->data() : table->table.data();
   if (! table_options.test(TL_OPTION_ALIAS) &&
       check_table_name(table->table.str, table->table.length))
   {
@@ -957,7 +957,7 @@
   ptr->derived=	    table->sel;
   ptr->select_lex=  lex->current_select;
   ptr->index_hints= index_hints_arg;
-  ptr->option= option ? option->str : 0;
+  ptr->option= option ? option->data() : NULL;
   /* check that used name is unique */
   if (lock_type != TL_IGNORE)
   {
@@ -1559,14 +1559,13 @@
                               bool no_error)
 {
   int well_formed_error;
-  uint32_t res= cs->cset->well_formed_len(cs, str->str, str->str + str->length,
-                                      max_char_length, &well_formed_error);
+  uint32_t res= cs->cset->well_formed_len(cs, str->begin(), str->end(), max_char_length, &well_formed_error);
 
   if (!well_formed_error &&  str->length == res)
     return false;
 
   if (!no_error)
-    my_error(ER_WRONG_STRING_LENGTH, MYF(0), str->str, err_msg, max_char_length);
+    my_error(ER_WRONG_STRING_LENGTH, MYF(0), str->data(), err_msg, max_char_length);
   return true;
 }
 
@@ -1583,12 +1582,11 @@
   const charset_info_st * const cs= &my_charset_utf8mb4_general_ci;
 
   int well_formed_error;
-  uint32_t res= cs->cset->well_formed_len(cs, str->str, str->str + str->length,
-                                      max_char_length, &well_formed_error);
+  uint32_t res= cs->cset->well_formed_len(cs, str->begin(), str->end(), max_char_length, &well_formed_error);
 
   if (well_formed_error)
   {
-    my_error(ER_INVALID_CHARACTER_STRING, MYF(0), "identifier", str->str);
+    my_error(ER_INVALID_CHARACTER_STRING, MYF(0), "identifier", str->data());
     return true;
   }
 
@@ -1600,14 +1598,13 @@
   case EE_OK:
     break;
   case ER_WRONG_STRING_LENGTH:
-    my_error(err_code, MYF(0), str->str, param_for_err_msg, max_char_length);
+    my_error(err_code, MYF(0), str->data(), param_for_err_msg, max_char_length);
     break;
   case ER_TOO_LONG_IDENT:
-    my_error(err_code, MYF(0), str->str);
+    my_error(err_code, MYF(0), str->data());
     break;
   default:
-    assert(0);
-    break;
+    assert(false);
   }
 
   return true;

=== modified file 'drizzled/statement/alter_schema.cc'
--- drizzled/statement/alter_schema.cc	2011-08-08 12:51:19 +0000
+++ drizzled/statement/alter_schema.cc	2011-10-10 12:58:39 +0000
@@ -42,7 +42,7 @@
   if (not validateSchemaOptions())
     return true;
 
-  identifier::Schema schema_identifier(string(db->str, db->length));
+  identifier::Schema schema_identifier(string(db->data(), db->size()));
 
   if (not schema::check(session(), schema_identifier))
   {
@@ -51,7 +51,7 @@
     return false;
   }
 
-  identifier::Schema identifier(db->str);
+  identifier::Schema identifier(db->data());
   if (not (old_definition= plugin::StorageEngine::getSchemaDefinition(identifier)))
   {
     my_error(ER_SCHEMA_DOES_NOT_EXIST, identifier); 

=== modified file 'drizzled/util/data_ref.h'
--- drizzled/util/data_ref.h	2011-10-10 09:27:50 +0000
+++ drizzled/util/data_ref.h	2011-10-10 12:58:39 +0000
@@ -54,11 +54,10 @@
     assign(b, strlen(b));
   }
 
-  const data_ref_basic& clear()
+  void clear()
   {
     begin_ = NULL;
     end_ = NULL;
-    return *this;
   }
 
   void assign(const void* b, const void* e)

=== modified file 'plugin/pbms/src/discover_ms.cc'
--- plugin/pbms/src/discover_ms.cc	2011-08-04 08:13:04 +0000
+++ plugin/pbms/src/discover_ms.cc	2011-10-10 12:58:39 +0000
@@ -658,7 +658,7 @@
 	break;
     case Key::FULLTEXT:
 	key_info->flags= HA_FULLTEXT;
-	if ((key_info->parser_name= &key->key_create_info.parser_name)->str)
+	if ((key_info->parser_name= &key->key_create_info.parser_name)->data())
           key_info->flags|= HA_USES_PARSER;
         else
           key_info->parser_name= 0;

